@@ -4,7 +4,7 @@ import os
 
 from mopidy import config, ext
 
-__version__ = '1.0.3'
+__version__ = '1.1.0'
 
 SORT_FIELDS = ['%s %s' % (f, o) for o in ('asc', 'desc') for f in (
     'addeddate',
@@ -57,16 +57,8 @@ class Extension(ext.Extension):
         schema['exclude_mediatypes'] = config.List(optional=True)
         schema['cache_size'] = config.Integer(minimum=1, optional=True)
         schema['cache_ttl'] = config.Integer(minimum=0, optional=True)
+        schema['retries'] = config.Integer(minimum=0)
         schema['timeout'] = config.Integer(minimum=0, optional=True)
-
-        # no longer used (for now)
-        schema['bookmarks'] = config.Deprecated()
-        schema['bookmarks_label'] = config.Deprecated()
-        schema['browse_label'] = config.Deprecated()
-        schema['excludes'] = config.Deprecated()
-        schema['mediatypes'] = config.Deprecated()
-        schema['sort_order'] = config.Deprecated()
-
         return schema
 
     def setup(self, registry):
