@@ -22,16 +22,15 @@ class InternetArchiveBackend(pykka.ThreadingActor, backend.Backend):
         super(InternetArchiveBackend, self).__init__()
         self.client = InternetArchiveClient(
             config[Extension.ext_name]['base_url'],
-            config[Extension.ext_name]['timeout'],
+            retries=config[Extension.ext_name]['retries'],
+            timeout=config[Extension.ext_name]['timeout']
         )
         self.library = InternetArchiveLibraryProvider(config, self)
         self.playback = InternetArchivePlaybackProvider(audio, self)
-
-        if config[Extension.ext_name]['username']:
-            self.playlists = InternetArchivePlaylistsProvider(config, self)
+        self.playlists = InternetArchivePlaylistsProvider(config, self)
 
     def on_start(self):
-        # give other backends a chance to load, too...
-        if self.playlists:
-            self.playlists.refresh()
-        super(InternetArchiveBackend, self).on_start()
+        self.playlists.start()
+
+    def on_stop(self):
+        self.playlists.stop()
